@@ -7,14 +7,10 @@ from .model import Model
 def Column(
     sqltype: TypeEngine,
     primary_key: bool = False,
+    nullable: bool = False,
 ): pass
 
 
-def create_all(bind='__all__', app=None):
-    pass
-
-
 class SQLAlchemy(SQLAlchemy):
     Model: Type[Model]
     Column: Column
-    create_all: create_all
